﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using Syncfusion.JavaScript;
using Syncfusion.JavaScript.Models;
using Syncfusion.EJ.Export;
using Syncfusion.XlsIO;
using System.Web.Script.Serialization;

namespace SpreadsheetSample.Controllers
{
    public partial class SpreadsheetController : Controller
    {
        public ActionResult SpreadsheetFeatures()
        {
            List<Sheet> sheets = new List<Sheet>();
            WorkbookProperties workbook = new WorkbookProperties()
            {
                SheetCount = 2,
                ActiveSheetIndex = 1,
                ColumnWidth = 100,
                ImportSettings = new SpreadsheetImportSettings() { ImportMapper = "Spreadsheet/Import" },
                ExportSettings = new SpreadsheetExportSettings() { ExcelUrl = "Spreadsheet/ExportToExcel", CsvUrl = "Spreadsheet/ExportToCsv", PdfUrl = "Spreadsheet/ExportToPdf" },
                Sheets = sheets
            };

            SpreadsheetCellStyles cellStyle = new SpreadsheetCellStyles() { BackgroundColor = "#EB7E2F", Color = "#ffffff", FontWeight = "Bold" };
            sheets.Add(new Sheet()
            {
                Rows = new List<Row>()
                {
                    new Row() 
                    {
                        Index = 0, //Row index
                        Cells = new List<Cell>()
                        { 
                            new Cell() { Value = "Item Name", Style = cellStyle, IsLocked =  true },
                            new Cell() { Value = "Quantity", Style = cellStyle, IsLocked =  true },
                            new Cell() { Value = "Price", Style = cellStyle, IsLocked =  true },
                            new Cell() { Value = "Amount", Style = cellStyle, IsLocked =  true }
                        }
                    },
                    new Row() 
                    {
                        Index = 1,
                        Cells = new List<Cell>()
                        {
                            new Cell() { Value = "Casual Shoes", IsLocked =  true },
                            new Cell() { Value = "10", IsLocked =  true },
                            new Cell() { Value = "20", Format = new NumFormat() { Type = "currency" }, IsLocked =  true },
                            new Cell() { Value = "=PRODUCT(B2,C2)", Format = new NumFormat() { Type = "currency" }, IsLocked =  true }
                        }
                    },
                    new Row() 
                    {
                        Cells = new List<Cell>()
                        {
                            new Cell() { Value = "Sports Shoes" },
                            new Cell() { Value = "20" },
                            new Cell() { Value = "30", Format = new NumFormat() { Type = "currency" } },
                            new Cell() { Value = "=PRODUCT(B3,C3)", Format = new NumFormat() { Type = "currency" } }
                        }
                    }
                }
            });

            ViewData["spreadsheetModel"] = workbook;
            return View();
        }

        [AcceptVerbs(HttpVerbs.Post)]
        public ActionResult Import(ImportRequest importRequest)
        {
            return importRequest.SpreadsheetActions();
        }

        [AcceptVerbs(HttpVerbs.Post)]
        public void ExportToExcel(string sheetModel, string sheetData, string password)
        {
            if (String.IsNullOrEmpty(password))
                Spreadsheet.Save(sheetModel, sheetData, "sample", ExportFormat.XLSX, ExcelVersion.Excel2013);
            else
                Spreadsheet.Save(sheetModel, sheetData, "sample", ExportFormat.XLSX, ExcelVersion.Excel2013, password);
        }

        [AcceptVerbs(HttpVerbs.Post)]
        public void ExportToCsv(string sheetModel, string sheetData)
        {
            Spreadsheet.Save(sheetModel, sheetData, "sample", ExportFormat.CSV);
        }

        [AcceptVerbs(HttpVerbs.Post)]
        public void ExportToPdf(string sheetModel, string sheetData)
        {
            Spreadsheet.Save(sheetModel, sheetData, "sample", ExportFormat.PDF);
        }
    }
}
